<?php
/**
 * Skeleton subclass for performing query and update operations on the 'ofertypracy' table.
 *
 *
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    lib.model
 */
class OfertypracyPeer extends BaseOfertypracyPeer {

    /**
     * Get number of objects with specified status that user can edit
     *
     * @param   int $status
     * @param   myUser $user Instance of myUser object
     * @return  int Number of object with specified status
     */
    public static function doCountByStatus($user, $status) {
        $permGlobal = $user->checkPermission('prac_global','edit') == 1 ? true : false;

        $c = new Criteria();
        $c->add(self::STATUS, $status);
        if(!$permGlobal)$c->add(self::UZYTKOWNIK_ID, $user->getId());

        return self::doCount($c);
    } 
    
    public static function AddByDate(Criteria $c = NULL) {
        if(!$c) {
            $c = new CriteriaExt();
        }
        
        //aktywne oferty z wypelniona data publikacji
        $a = $c->getNewCriterion(OfertypracyPubPeer::PUBLIKACJA_DO, date('Y-m-d H:i:s'), Criteria::GREATER_EQUAL);
        $b = $c->getNewCriterion(OfertypracyPubPeer::PUBLIKACJA_OD, date('Y-m-d H:i:s'), Criteria::LESS_EQUAL);

        $a->addAnd($b);

        //lub oferty bez wypelnionej daty publikacji ale aktywny
        $y = $c->getNewCriterion(OfertypracyPubPeer::PUBLIKACJA_OD, null, Criteria::ISNULL);
        $z = $c->getNewCriterion(OfertypracyPubPeer::PUBLIKACJA_DO, null, Criteria::ISNULL);
        $y->addAnd($z);

        $a->addOr($y);

        $c->add($a);

        return $c;
    }
    
    /**
     * Metoda do konwersji identyfikatora formy aktywizacji na jej nazwe.
     * Jesli podany jest konkretny id, metoda zwraca String z nazwa lub 
     * false, jesli nie znajdzie. Wywolana bez parametru zwraca
     * Array z lista (id, nazwa).
     * @author      Tomasz Glowinski, 2012
     * @param       Integer $id identyfikator [opcjonalny]
     * return       Array lista wszystkich form aktywizacji, jesli nie ma 
     *              parametru; Boolean false, gdy parametr jest bledny lub
     *              nie odnaleziono danego numeru formy aktywizacji
     */
    public static function getRodzajAktywizacji($id = null)
    {
        $current_list = array(
            '211'   =>  'Oferta pracy stałej zgłoszona przez pracodawcę',
            '434'   =>  'Oferta stażu dla bezrobotnych - osób w szczególnej sytuacji na rynku pracy',
            '552'   =>  'Oferta stażu z PFRON dla niepełnosprawnych',
            '433'   =>  'Oferta z Robót Publicznych dla bezrobotnych - osób w szczególnej sytuacji na rynku pracy',
            '432'   =>  'Oferta z Prac Interwencyjnych dla bezrobotnych - osób w szczególnej sytuacji na rynku pracy',
        );
        
        if(!empty($id))
        {
            if(is_numeric($id) && in_array($id, $current_list))
                return $current_list[$id];
            else
                return false;
        }
        
        return $current_list;
    }
    
    public static function usunPrzeterminowane() {
        $con = Propel::getConnection();
        
        $criteria = new Criteria();
        $criteria->add(OfertypracyPeer::PUBLIKACJA_DO, OfertypracyPeer::PUBLIKACJA_DO . '<= NOW()', Criteria::CUSTOM);
        $criteria->add(OfertypracyPeer::OFERTA_ZASIEG, 211, Criteria::EQUAL);
        BasePeer::doDelete($criteria, $con);
    }
}
