<?php

class OfertypracyPub extends BaseOfertypracyPub
{

    public function getJunk($lang = null)
    {
        if(!$lang)
            $lang = sfPropel::getDefaultCulture();
        $zawod = $this->getOfertaNazwaZawodu($lang);
        $zawod = Functions::slugify($zawod);
        return $zawod;
    }

    public function __toString()
    {
        return $this->getOfertaNazwaZawodu(sfContext::getInstance()->getUser()->getCulture());
    }

    
    public function save(PropelPDO $con = null)
    {
        if(is_null($con))
        {
            $con = Propel::getConnection(AktualnoscPubPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
        }

        $con->beginTransaction();
        try
        {
            $ret = parent::save($con);

            $this->updateLuceneIndex();

            $con->commit();

            return $ret;
        }
        catch (Exception $e)
        {
            $con->rollBack();
            throw $e;
        }
    }
    
    public function delete(PropelPDO $con = null)
    {
        // aktualizacja indexu Lucene
        $index = Functions::getLuceneIndex('prac');
        foreach($index->find('pk:'.$this->getId()) as $hit)
            $index->delete($hit->id);
        
        return parent::delete($con);
    }
    
    /**
     * metoda aktualizujaca indeks Lucene
     * @author      Tomasz Glowinski, 2014
     */
    public function updateLuceneIndex()
    {        
        $index = Functions::getLuceneIndex('prac');

        // remove existing entries
        foreach($index->find('pk:'.$this->getId()) as $hit)
            $index->delete($hit->id);

        $doc = new Zend_Search_Lucene_Document();

        // store job primary key to identify it in the search results
        $doc->addField(Zend_Search_Lucene_Field::Keyword('pk', $this->getId()));

        // index job fields
        $culture = sfContext::getInstance()->getUser()->getCulture();
        $jezyk = Zend_Search_Lucene_Field::UnStored('jezyk', $culture, 'utf-8');
        $doc->addField($jezyk);
        $tytul = Zend_Search_Lucene_Field::UnStored('tytul', strip_tags($this->getOfertaNazwaZawodu()), 'utf-8');
        $doc->addField($tytul);
        $zajawka = Zend_Search_Lucene_Field::UnStored('zajawka', strip_tags($this->getOfertaNazwaStanowiska()), 'utf-8');
        $doc->addField($zajawka);
        $tresc = Zend_Search_Lucene_Field::UnStored('tresc', strip_tags($this->getOfertaOpisZawodu()), 'utf-8');
        $doc->addField($tresc);
        $miasto = Zend_Search_Lucene_Field::UnStored('miasto', strip_tags($this->getOfertaMiejsceWykonywaniaPracy()), 'utf-8');
        $doc->addField($miasto);
        $umowa = Zend_Search_Lucene_Field::UnStored('umowa', strip_tags($this->getOfertaRodzajUmowy()), 'utf-8');
        $doc->addField($umowa);
        $pracodawca = Zend_Search_Lucene_Field::UnStored('pracodawca', strip_tags($this->getPracodawcaNazwa()), 'utf-8');
        $doc->addField($pracodawca);
        
        // add job to the index
        $index->addDocument($doc);
        
        $index->optimize();
        
        $index->commit();
    }
    
}
